@@ -2,5 +2,7 @@
 from .aggregation_primitives import *
 from .binary_transform import *
 from .cum_transform_feature import *
+from .datetime_transform_primitives import *
+from .latlong_transform_primitives import *
 from .rolling_transform_primitive import *
 from .transform_primitive import *
