@@ -207,6 +207,8 @@ class DeepFeatureSynthesis(object):
                 df_library = library
                 break
 
+        aggregation_primitive_dict = primitives.get_aggregation_primitives()
+        transform_primitive_dict = primitives.get_transform_primitives()
         if agg_primitives is None:
             agg_primitives = [
                 p
@@ -215,7 +217,15 @@ class DeepFeatureSynthesis(object):
             ]
         self.agg_primitives = []
         self.agg_primitives = sorted(
-            [check_primitive(p, "aggregation") for p in agg_primitives]
+            [
+                check_primitive(
+                    p,
+                    "aggregation",
+                    aggregation_primitive_dict,
+                    transform_primitive_dict,
+                )
+                for p in agg_primitives
+            ]
         )
 
         if trans_primitives is None:
@@ -225,19 +235,37 @@ class DeepFeatureSynthesis(object):
                 if df_library in p.compatibility
             ]
         self.trans_primitives = sorted(
-            [check_primitive(p, "transform") for p in trans_primitives]
+            [
+                check_primitive(
+                    p, "transform", aggregation_primitive_dict, transform_primitive_dict
+                )
+                for p in trans_primitives
+            ]
         )
 
         if where_primitives is None:
             where_primitives = [primitives.Count]
         self.where_primitives = sorted(
-            [check_primitive(p, "where") for p in where_primitives]
+            [
+                check_primitive(
+                    p, "where", aggregation_primitive_dict, transform_primitive_dict
+                )
+                for p in where_primitives
+            ]
         )
 
         if groupby_trans_primitives is None:
             groupby_trans_primitives = []
         self.groupby_trans_primitives = sorted(
-            [check_primitive(p, "groupby transform") for p in groupby_trans_primitives]
+            [
+                check_primitive(
+                    p,
+                    "groupby transform",
+                    aggregation_primitive_dict,
+                    transform_primitive_dict,
+                )
+                for p in groupby_trans_primitives
+            ]
         )
 
         if primitive_options is None:
@@ -637,10 +665,8 @@ class DeepFeatureSynthesis(object):
             )
             if ignore_dataframe_for_primitive(current_options, dataframe):
                 continue
-            # if multiple input_types, only use first one for DFS
+
             input_types = trans_prim.input_types
-            if type(input_types[0]) == list:
-                input_types = input_types[0]
 
             matching_inputs = self._get_matching_inputs(
                 all_features,
@@ -666,9 +692,6 @@ class DeepFeatureSynthesis(object):
             if ignore_dataframe_for_primitive(current_options, dataframe, groupby=True):
                 continue
             input_types = groupby_prim.input_types[:]
-            # if multiple input_types, only use first one for DFS
-            if type(input_types[0]) == list:
-                input_types = input_types[0]
             matching_inputs = self._get_matching_inputs(
                 all_features,
                 dataframe,
@@ -772,10 +795,6 @@ class DeepFeatureSynthesis(object):
 
             if ignore_dataframe_for_primitive(current_options, child_dataframe):
                 continue
-            # if multiple input_types, only use first one for DFS
-            input_types = agg_prim.input_types
-            if type(input_types[0]) == list:
-                input_types = input_types[0]
 
             def feature_filter(f):
                 # Remove direct features of parent dataframe and features in relationship path.
@@ -783,6 +802,7 @@ class DeepFeatureSynthesis(object):
                     not _direct_of_dataframe(f, parent_dataframe)
                 ) and not self._feature_in_relationship_path(relationship_path, f)
 
+            input_types = agg_prim.input_types
             matching_inputs = self._get_matching_inputs(
                 all_features,
                 child_dataframe,
@@ -922,21 +942,28 @@ class DeepFeatureSynthesis(object):
         feature_filter=None,
     ):
 
-        features = self._features_by_type(
-            all_features=all_features,
-            dataframe=dataframe,
-            max_depth=max_depth,
-            column_schemas=list(input_types),
-        )
-        if feature_filter:
-            features = [f for f in features if feature_filter(f)]
+        if not isinstance(input_types[0], list):
+            input_types = [input_types]
+        matching_inputs = []
 
-        matching_inputs = match(
-            input_types,
-            features,
-            commutative=primitive.commutative,
-            require_direct_input=require_direct_input,
-        )
+        for input_type in input_types:
+            features = self._features_by_type(
+                all_features=all_features,
+                dataframe=dataframe,
+                max_depth=max_depth,
+                column_schemas=list(input_type),
+            )
+            if feature_filter:
+                features = [f for f in features if feature_filter(f)]
+
+            matches = match(
+                input_type,
+                features,
+                commutative=primitive.commutative,
+                require_direct_input=require_direct_input,
+            )
+
+            matching_inputs.extend(matches)
 
         if require_direct_input:
             # Don't create trans features of inputs which are all direct
@@ -1087,9 +1114,11 @@ def handle_primitive(primitive):
     return primitive
 
 
-def check_primitive(primitive, prim_type):
+def check_primitive(
+    primitive, prim_type, aggregation_primitive_dict, transform_primitive_dict
+):
     if prim_type == "transform" or prim_type == "groupby transform":
-        prim_dict = primitives.get_transform_primitives()
+        prim_dict = transform_primitive_dict
         supertype = TransformPrimitive
         arg_name = (
             "trans_primitives"
@@ -1098,7 +1127,7 @@ def check_primitive(primitive, prim_type):
         )
         s = "a transform"
     if prim_type == "aggregation" or prim_type == "where":
-        prim_dict = primitives.get_aggregation_primitives()
+        prim_dict = aggregation_primitive_dict
         supertype = AggregationPrimitive
         arg_name = (
             "agg_primitives" if prim_type == "aggregation" else "where_primitives"
