@@ -3,8 +3,16 @@ import pandas as pd
 import featuretools as ft
 from featuretools.entityset.deserialize import description_to_entityset
 from featuretools.feature_base.features_serializer import FeaturesSerializer
+from featuretools.primitives import (
+    Count,
+    Max,
+    MultiplyNumericScalar,
+    NMostCommon,
+    NumUnique,
+)
+from featuretools.primitives.utils import serialize_primitive
 
-SCHEMA_VERSION = "8.0.0"
+SCHEMA_VERSION = "9.0.0"
 
 
 def test_single_feature(es):
@@ -17,6 +25,7 @@ def test_single_feature(es):
         "entityset": es.to_dictionary(),
         "feature_list": [feature.unique_name()],
         "feature_definitions": {feature.unique_name(): feature.to_dictionary()},
+        "primitive_definitions": {},
     }
 
     _compare_feature_dicts(expected, serializer.to_dict())
@@ -24,7 +33,7 @@ def test_single_feature(es):
 
 def test_base_features_in_list(es):
     value = ft.IdentityFeature(es["log"].ww["value"])
-    max_feature = ft.AggregationFeature(value, "sessions", ft.primitives.Max)
+    max_feature = ft.AggregationFeature(value, "sessions", Max)
     features = [max_feature, value]
     serializer = FeaturesSerializer(features)
 
@@ -38,13 +47,19 @@ def test_base_features_in_list(es):
             value.unique_name(): value.to_dictionary(),
         },
     }
+    expected["primitive_definitions"] = {"0": serialize_primitive(Max())}
+    expected["feature_definitions"][max_feature.unique_name()]["arguments"][
+        "primitive"
+    ] = "0"
 
-    _compare_feature_dicts(expected, serializer.to_dict())
+    actual = serializer.to_dict()
+    _compare_feature_dicts(expected, actual)
 
 
 def test_multi_output_features(es):
     product_id = ft.IdentityFeature(es["log"].ww["product_id"])
-    threecommon = ft.primitives.NMostCommon()
+    threecommon = NMostCommon()
+    num_unique = NumUnique()
     tc = ft.Feature(product_id, parent_dataframe_name="sessions", primitive=threecommon)
 
     features = [tc, product_id]
@@ -53,7 +68,7 @@ def test_multi_output_features(es):
             ft.Feature(
                 tc[i],
                 parent_dataframe_name="customers",
-                primitive=ft.primitives.NumUnique,
+                primitive=num_unique,
             )
         )
         features.append(tc[i])
@@ -71,15 +86,26 @@ def test_multi_output_features(es):
         "feature_list": flist,
         "feature_definitions": fdict,
     }
-    actual = serializer.to_dict()
+    expected["primitive_definitions"] = {
+        "0": serialize_primitive(threecommon),
+        "1": serialize_primitive(num_unique),
+    }
 
+    expected["feature_definitions"][flist[0]]["arguments"]["primitive"] = "0"
+    expected["feature_definitions"][flist[2]]["arguments"]["primitive"] = "1"
+    expected["feature_definitions"][flist[4]]["arguments"]["primitive"] = "1"
+    expected["feature_definitions"][flist[6]]["arguments"]["primitive"] = "1"
+
+    actual = serializer.to_dict()
     _compare_feature_dicts(expected, actual)
 
 
 def test_base_features_not_in_list(es):
+    max_primitive = Max()
+    mult_primitive = MultiplyNumericScalar(value=2)
     value = ft.IdentityFeature(es["log"].ww["value"])
-    value_x2 = ft.TransformFeature(value, ft.primitives.MultiplyNumericScalar(value=2))
-    max_feature = ft.AggregationFeature(value_x2, "sessions", ft.primitives.Max)
+    value_x2 = ft.TransformFeature(value, mult_primitive)
+    max_feature = ft.AggregationFeature(value_x2, "sessions", max_primitive)
     features = [max_feature]
     serializer = FeaturesSerializer(features)
 
@@ -94,15 +120,27 @@ def test_base_features_not_in_list(es):
             value.unique_name(): value.to_dictionary(),
         },
     }
+    expected["primitive_definitions"] = {
+        "0": serialize_primitive(max_primitive),
+        "1": serialize_primitive(mult_primitive),
+    }
+    expected["feature_definitions"][max_feature.unique_name()]["arguments"][
+        "primitive"
+    ] = "0"
+    expected["feature_definitions"][value_x2.unique_name()]["arguments"][
+        "primitive"
+    ] = "1"
 
-    _compare_feature_dicts(expected, serializer.to_dict())
+    actual = serializer.to_dict()
+    _compare_feature_dicts(expected, actual)
 
 
 def test_where_feature_dependency(es):
+    max_primitive = Max()
     value = ft.IdentityFeature(es["log"].ww["value"])
     is_purchased = ft.IdentityFeature(es["log"].ww["purchased"])
     max_feature = ft.AggregationFeature(
-        value, "sessions", ft.primitives.Max, where=is_purchased
+        value, "sessions", max_primitive, where=is_purchased
     )
     features = [max_feature]
     serializer = FeaturesSerializer(features)
@@ -118,15 +156,23 @@ def test_where_feature_dependency(es):
             is_purchased.unique_name(): is_purchased.to_dictionary(),
         },
     }
+    expected["primitive_definitions"] = {
+        "0": serialize_primitive(max_primitive),
+    }
+    expected["feature_definitions"][max_feature.unique_name()]["arguments"][
+        "primitive"
+    ] = "0"
 
-    _compare_feature_dicts(expected, serializer.to_dict())
+    actual = serializer.to_dict()
+    _compare_feature_dicts(expected, actual)
 
 
 def test_feature_use_previous_pd_timedelta(es):
     value = ft.IdentityFeature(es["log"].ww["id"])
     td = pd.Timedelta(12, "W")
+    count_primitive = Count()
     count_feature = ft.AggregationFeature(
-        value, "customers", ft.primitives.Count, use_previous=td
+        value, "customers", count_primitive, use_previous=td
     )
     features = [count_feature, value]
     serializer = FeaturesSerializer(features)
@@ -141,15 +187,21 @@ def test_feature_use_previous_pd_timedelta(es):
             value.unique_name(): value.to_dictionary(),
         },
     }
+    expected["primitive_definitions"] = {"0": serialize_primitive(count_primitive)}
+    expected["feature_definitions"][count_feature.unique_name()]["arguments"][
+        "primitive"
+    ] = "0"
 
-    _compare_feature_dicts(expected, serializer.to_dict())
+    actual = serializer.to_dict()
+    _compare_feature_dicts(expected, actual)
 
 
 def test_feature_use_previous_pd_dateoffset(es):
     value = ft.IdentityFeature(es["log"].ww["id"])
     do = pd.DateOffset(months=3)
+    count_primitive = Count()
     count_feature = ft.AggregationFeature(
-        value, "customers", ft.primitives.Count, use_previous=do
+        value, "customers", count_primitive, use_previous=do
     )
     features = [count_feature, value]
     serializer = FeaturesSerializer(features)
@@ -164,13 +216,18 @@ def test_feature_use_previous_pd_dateoffset(es):
             value.unique_name(): value.to_dictionary(),
         },
     }
+    expected["primitive_definitions"] = {"0": serialize_primitive(count_primitive)}
+    expected["feature_definitions"][count_feature.unique_name()]["arguments"][
+        "primitive"
+    ] = "0"
 
-    _compare_feature_dicts(expected, serializer.to_dict())
+    actual = serializer.to_dict()
+    _compare_feature_dicts(expected, actual)
 
     value = ft.IdentityFeature(es["log"].ww["id"])
     do = pd.DateOffset(months=3, days=2, minutes=30)
     count_feature = ft.AggregationFeature(
-        value, "customers", ft.primitives.Count, use_previous=do
+        value, "customers", count_primitive, use_previous=do
     )
     features = [count_feature, value]
     serializer = FeaturesSerializer(features)
@@ -185,8 +242,12 @@ def test_feature_use_previous_pd_dateoffset(es):
             value.unique_name(): value.to_dictionary(),
         },
     }
-
-    _compare_feature_dicts(expected, serializer.to_dict())
+    expected["primitive_definitions"] = {"0": serialize_primitive(count_primitive)}
+    expected["feature_definitions"][count_feature.unique_name()]["arguments"][
+        "primitive"
+    ] = "0"
+    actual = serializer.to_dict()
+    _compare_feature_dicts(expected, actual)
 
 
 def _compare_feature_dicts(a_dict, b_dict):
