@@ -15,7 +15,10 @@ from featuretools.primitives import (
     IsMonthStart,
     IsQuarterEnd,
     IsQuarterStart,
+    IsYearEnd,
+    IsYearStart,
     NumericLag,
+    PartOfDay,
     Quarter,
     TimeSince,
     URLToDomain,
@@ -114,19 +117,19 @@ def test_age_nan():
 
 def test_day_of_year():
     doy = DayOfYear()
-    dates = pd.Series([datetime(2019, 12, 31), datetime(2020, 12, 31)])
+    dates = pd.Series([datetime(2019, 12, 31), np.nan, datetime(2020, 12, 31)])
     days_of_year = doy(dates)
-    correct_days = [365, 366]
+    correct_days = [365, np.nan, 366]
     np.testing.assert_array_equal(days_of_year, correct_days)
 
 
 def test_days_in_month():
     dim = DaysInMonth()
     dates = pd.Series(
-        [datetime(2010, 1, 1), datetime(2019, 2, 1), datetime(2020, 2, 1)]
+        [datetime(2010, 1, 1), datetime(2019, 2, 1), np.nan, datetime(2020, 2, 1)]
     )
     days_in_month = dim(dates)
-    correct_days = [31, 28, 29]
+    correct_days = [31, 28, np.nan, 29]
     np.testing.assert_array_equal(days_in_month, correct_days)
 
 
@@ -174,6 +177,54 @@ def test_is_quarter_start():
     np.testing.assert_array_equal(iqs_bools, correct_bools)
 
 
+def test_part_of_day():
+    pod = PartOfDay()
+    dates = pd.Series(
+        [
+            datetime(2020, 1, 11, 1, 2, 1),
+            datetime(2021, 3, 31, 4, 2, 1),
+            datetime(2020, 3, 4, 6, 2, 1),
+            datetime(2020, 3, 4, 8, 2, 1),
+            datetime(2020, 3, 4, 11, 2, 1),
+            datetime(2020, 3, 4, 14, 2, 3),
+            datetime(2020, 3, 4, 17, 2, 3),
+            datetime(2020, 2, 2, 20, 2, 2),
+            np.nan,
+        ]
+    )
+    actual = pod(dates)
+    expected = pd.Series(
+        [
+            "midnight",
+            "dawn",
+            "early morning",
+            "late morning",
+            "noon",
+            "afternoon",
+            "evening",
+            "night",
+            np.nan,
+        ]
+    )
+    pd.testing.assert_series_equal(expected, actual)
+
+
+def test_is_year_end():
+    is_year_end = IsYearEnd()
+    dates = pd.Series([datetime(2020, 12, 31), np.nan, datetime(2020, 1, 1)])
+    answer = is_year_end(dates)
+    correct_answer = [True, False, False]
+    np.testing.assert_array_equal(answer, correct_answer)
+
+
+def test_is_year_start():
+    is_year_start = IsYearStart()
+    dates = pd.Series([datetime(2020, 12, 31), np.nan, datetime(2020, 1, 1)])
+    answer = is_year_start(dates)
+    correct_answer = [False, False, True]
+    np.testing.assert_array_equal(answer, correct_answer)
+
+
 def test_quarter_regular():
     q = Quarter()
     array = pd.Series(
