@@ -6,6 +6,7 @@ from featuretools.primitives import (
     Count,
     Hour,
     IsIn,
+    Not,
     TimeSincePrevious,
     TransformPrimitive,
 )
@@ -111,3 +112,27 @@ def test_get_valid_primitives_single_table(transform_es):
 
     assert set(agg_prims) == set()
     assert IsIn in trans_prims
+
+
+def test_get_valid_primitives_with_dfs_kwargs(es):
+    agg_prims, trans_prims = get_valid_primitives(
+        es, "customers", selected_primitives=[Hour, Count, Not]
+    )
+    assert set(agg_prims) == set([Count])
+    assert set(trans_prims) == set([Hour, Not])
+
+    # Can use other dfs parameters and they get applied
+    agg_prims, trans_prims = get_valid_primitives(
+        es,
+        "customers",
+        selected_primitives=[Hour, Count, Not],
+        ignore_columns={"customers": ["loves_ice_cream"]},
+    )
+    assert set(agg_prims) == set([Count])
+    assert set(trans_prims) == set([Hour])
+
+    agg_prims, trans_prims = get_valid_primitives(
+        es, "products", selected_primitives=[Hour, Count], ignore_dataframes=["log"]
+    )
+    assert set(agg_prims) == set()
+    assert set(trans_prims) == set()
