@@ -3,11 +3,11 @@ import pandas as pd
 
 from featuretools.utils.gen_utils import import_or_none, is_instance
 
-ps = import_or_none('pyspark.pandas')
+ps = import_or_none("pyspark.pandas")
 
 
 def to_pandas(df, index=None, sort_index=False, int_index=False):
-    '''
+    """
     Testing util to convert dataframes to pandas. If a pandas dataframe is passed in, just returns the dataframe.
 
     Args:
@@ -17,13 +17,13 @@ def to_pandas(df, index=None, sort_index=False, int_index=False):
 
     Returns:
         Pandas DataFrame
-    '''
+    """
     if isinstance(df, (pd.DataFrame, pd.Series)):
         return df
 
     if isinstance(df, (dd.DataFrame, dd.Series)):
         pd_df = df.compute()
-    if is_instance(df, (ps, ps), ('DataFrame', 'Series')):
+    if is_instance(df, (ps, ps), ("DataFrame", "Series")):
         pd_df = df.to_pandas()
 
     if index:
@@ -37,9 +37,12 @@ def to_pandas(df, index=None, sort_index=False, int_index=False):
 
 
 def get_df_tags(df):
-    '''Gets a DataFrame's semantic tags without index or time index tags for Woodwork init'''
+    """Gets a DataFrame's semantic tags without index or time index tags for Woodwork init"""
     semantic_tags = {}
     for col_name in df.columns:
-        semantic_tags[col_name] = df.ww.semantic_tags[col_name] - {'time_index', 'index'}
+        semantic_tags[col_name] = df.ww.semantic_tags[col_name] - {
+            "time_index",
+            "index",
+        }
 
     return semantic_tags
